@@ -14,7 +14,7 @@
 checkConv <- function(derivs, coefs, ctrl, lbound, debug = FALSE)
 {
     if (is.null(derivs)) return(NULL)  ## bail out
-    if (any(is.na(derivs$gradient)))
+    if (anyNA(derivs$gradient))
 	return(list(code = -5L,
 		    messages = gettextf("Gradient contains NAs")))
     ntheta <- length(lbound)
@@ -24,16 +24,23 @@ checkConv <- function(derivs, coefs, ctrl, lbound, debug = FALSE)
     ccl <- ctrl[[cstr <- "check.conv.grad"]] ; checkCtrlLevels(cstr, cc <- ccl[["action"]])
     wstr <- NULL
     if (doCheck(cc)) {
-        scgrad <- try(with(derivs,solve(Hessian,gradient)),silent=TRUE)
-        if (inherits(scgrad,"try-error")) {
+        scgrad <- tryCatch(with(derivs,solve(chol(Hessian),gradient)),
+                           error=function(e)e)
+        if (inherits(scgrad, "error")) {
             wstr <- "unable to evaluate scaled gradient"
             res$code <- -1L
         } else {
-            if ((max.grad <- max(abs(scgrad))) > ccl$tol) {
-                w <- which.max(abs(scgrad))
+            ## find parallel *minimum* of scaled and absolute gradient
+            ## the logic here is that we can sometimes get large
+            ##  *scaled* gradients even when the *absolute* gradient
+            ##  is small because the curvature is very flat as well ...
+            mingrad <- pmin(abs(scgrad),abs(derivs$gradient))
+            maxmingrad <- max(mingrad)
+            if (maxmingrad > ccl$tol) {
+                w <- which.max(maxmingrad)
                 res$code <- -1L
                 wstr <- gettextf("Model failed to converge with max|grad| = %g (tol = %g, component %d)",
-                                 max.grad, ccl$tol,w)
+                                 maxmingrad, ccl$tol,w)
             }
         }
         if (!is.null(wstr)) {
@@ -109,43 +116,50 @@ checkConv <- function(derivs, coefs, ctrl, lbound, debug = FALSE)
 }
 
 checkHess <- function(H, tol, hesstype="") {
+    ## FIXME: not sure why we decided to save messages as a list
+    ## rather than as a character vector??
     res <- list(code=numeric(0),messages=list())
-    evd <- eigen(H, symmetric=TRUE, only.values=TRUE)$values
-    negative <- sum(evd < -tol)
-    if(negative) {
-        res$code <- -3L
-        res$messages <-
-            gettextf(paste("Model failed to converge:",
-                           "degenerate",hesstype,"Hessian with %d negative eigenvalues"),
-                     negative)
+    evd <- tryCatch(eigen(H, symmetric=TRUE, only.values=TRUE)$values,
+                    error=function(e)e)
+    if (inherits(evd,"error")) {
+        res$code <- -6L
+        res$messages <- gettextf("Problem with Hessian check (infinite or missing values?)")
     } else {
-        zero <- sum(abs(evd) < tol)
-        ch <- try(chol(H), silent=TRUE)
-        if(zero || inherits(ch, "try-error")) {
-            res$code <- -4L
+        negative <- sum(evd < -tol)
+        if(negative) {
+            res$code <- -3L
             res$messages <-
-                paste(hesstype,"Hessian is numerically singular: parameters are not uniquely determined")
+                gettextf(paste("Model failed to converge:",
+                               "degenerate",hesstype,"Hessian with %d negative eigenvalues"),
+                         negative)
         } else {
-            res$cond.H <- max(evd) / min(evd)
-            if(max(evd) * tol > 1) {
-                res$code <- c(res$code, 2L)
+            zero <- sum(abs(evd) < tol)
+            if(zero || inherits(tryCatch(chol(H), error=function(e)e), "error")) {
+                res$code <- -4L
                 res$messages <-
-                    c(res$messages,
-                      paste("Model is nearly unidentifiable: ",
-                            "very large eigenvalue",
-                            "\n - Rescale variables?", sep=""))
-            }
-            if ((min(evd) / max(evd)) < tol) {
-                res$code <- c(res$code, 3L)
-                ## consider skipping warning message if we've
-                ## already hit the previous flag?
-                if(!5L %in% res$code) {
+                    paste(hesstype,"Hessian is numerically singular: parameters are not uniquely determined")
+            } else {
+                res$cond.H <- max(evd) / min(evd)
+                if(max(evd) * tol > 1) {
+                    res$code <- c(res$code, 2L)
                     res$messages <-
                         c(res$messages,
                           paste("Model is nearly unidentifiable: ",
-                                "large eigenvalue ratio",
+                                "very large eigenvalue",
                                 "\n - Rescale variables?", sep=""))
                 }
+                if ((min(evd) / max(evd)) < tol) {
+                    res$code <- c(res$code, 3L)
+                    ## consider skipping warning message if we've
+                    ## already hit the previous flag?
+                    if(!5L %in% res$code) {
+                        res$messages <-
+                            c(res$messages,
+                              paste("Model is nearly unidentifiable: ",
+                                    "large eigenvalue ratio",
+                                    "\n - Rescale variables?", sep=""))
+                    }
+                }
             }
         }
     }
@@ -218,8 +232,7 @@ checkHess <- function(H, tol, hesstype="") {
 ##         return(res)
 ##     }
 ##     zero <- sum(abs(evd) < tol)
-##     ch <- try(chol(H), silent=TRUE)
-##     if(zero || inherits(ch, "try-error")) {
+##     if(zero || inherits(tryCatch(chol(H), error=function(e)e), "error")) {
 ##         res$code <- 1L
 ##         res$messages <-
 ##             "Hessian is numerically singular: parameters are not uniquely determined"
